Class: RDialogy::Editbox

Inherits:
FilePathWidget show all
Defined in:
lib/rdialogy/editbox.rb

Class Method Summary collapse

Class Method Details

.run(options = {}) ⇒ Object

Valid options are:

  • :path - Path to file to display
  • :width
  • :height

From the man page:

The edit-box dialog displays a copy of the file. You may edit it using the backspace, delete and cursor keys to correct typing errors. It also recognizes pageup/pagedown. Unlike the --inputbox, you must tab to the "OK" or "Cancel" buttons to close the dialog. Pressing the "Enter" key within the box will split the corresponding line.



18
19
20
# File 'lib/rdialogy/editbox.rb', line 18

def self.run(options={})
  super options
end